@@ -381,6 +381,9 @@ class ConnectionState:
         # the keys of self._guilds are ints
         return self._guilds.get(guild_id)  # type: ignore
 
+    def _get_or_create_unavailable_guild(self, guild_id: int) -> Guild:
+        return self._guilds.get(guild_id) or Guild._create_unavailable(state=self, guild_id=guild_id)
+
     def _add_guild(self, guild: Guild) -> None:
         self._guilds[guild.id] = guild
 
